@@ -1,8 +1,9 @@
 # referencing the fetchers for the PyPI package
 
 from .fanfox import Fanfox
-from .mangadex import Mangadex
+from .mangadex import Mangadex, MangadexEN, MangadexFR
 from .nh import NHentai
+from .frscan import FRScan
 
 # naver webtoons
 from .naver import NaverWebtoon
